function [M] = Untitled2(phi,teta,psi)
%Converte os angulos de Euler(phi,teta,psi) numa matriz de transformaçao M
%   phi - angulo em z
%   teta - angulo em y
%   psi- angulo em x
M=rotz(phi)*roty(teta)*rotx(psi);
end

